@@ -71,6 +71,16 @@ class TestIndexParsing:
         assert link.eggfragment == "py-dev"
         assert link2.basename == "py-1.0.zip"
 
+    def test_parse_index_ftp_ignored_for_now(self):
+        result = parse_index(self.simplepy,
+            """<a href="http://bb.org/download/py-1.0.zip" />
+               <a href="ftp://bb.org/download/py-1.0.tar.gz" />
+               <a rel="download" href="ftp://bb.org/download/py-1.1.tar.gz" />
+        """)
+        assert len(result.releaselinks) == 1
+        link, = result.releaselinks
+        assert link.basename == "py-1.0.zip"
+
     def test_parse_index_with_two_eggs_ordering(self):
         # it seems that pip/easy_install in some cases
         # rely on the exact ordering of eggs in the html page
@@ -112,6 +122,14 @@ class TestIndexParsing:
                 "http://pypi.python.org/pkg/py-1.4.12.zip#md5=12ab"
         assert links[1].url == "http://pylib.org/py-1.1.egg"
 
+    def test_releasefile_and_scrape_no_ftp(self):
+        result = parse_index(self.simplepy,
+            """<a href="ftp://pylib2.org/py-1.0.tar.gz"
+                  rel="download">whatever2</a> """)
+        assert len(result.releaselinks) == 0
+        assert len(result.crawllinks) == 0
+
+
     def test_releasefile_md5_matching_and_ordering(self):
         """ check that md5-links win over non-md5 links anywhere.
         And otherwise the links from the index page win over scraped ones.
@@ -150,6 +168,27 @@ class TestExtPYPIDB:
         assert link.md5 == "123"
         assert link.relpath.endswith("/pytest-1.0.zip")
 
+    def test_getprojectconfig(self, extdb):
+        extdb.setextsimple("pytest", text='''
+            <a href="../../pkg/pytest-1.0.zip#md5=123" />''')
+        config = extdb.get_projectconfig("pytest")
+        data = config["1.0"]
+        assert data["+files"]
+
+    def test_getdescription(self, extdb):
+        extdb.setextsimple("pytest", text='''
+            <a href="../../pkg/pytest-1.0.zip#md5=123" />''')
+        content = extdb.get_description("pytest", "1.0")
+        assert "refer" in content
+        assert "https://pypi.python.org/pypi/pytest/1.0/" in content
+
+    def test_getprojectconfig_with_egg(self, extdb):
+        extdb.setextsimple("pytest", text='''
+            <a href="../../pkg/tip.zip#egg=pytest-dev" />''')
+        config = extdb.get_projectconfig("pytest")
+        data = config["egg=pytest-dev"]
+        assert data["+files"]
+
     def test_parse_and_scrape(self, extdb):
         extdb.setextsimple("pytest", text='''
                 <a href="../../pkg/pytest-1.0.zip#md5=123" />
